@@ -13,8 +13,9 @@ use Exporter;
 use parent 'Exporter';
 
 #设备版本信息和默认导出函数
-our $VERSION = 0.06;
-our @EXPORT = qw 'ip_info info_parser device_arp device_mac device_nei device_eth device_info';
+our $VERSION = 0.07;
+our @EXPORT
+    = qw 'ip_info info_parser device_arp device_mac device_nei device_eth device_info';
 
 #------------------------------------------------------------------------------
 # 常量 ip_str mac_str 数据格式
@@ -94,7 +95,7 @@ sub ip_info {
         #获取当前设备的 mac_info 哈希对象
         my $device_mac = $mac_info->{$device};
 
-     	#阶段一 -- 获取设备自身IP地址，索引为设备下自身接口
+        #阶段一 -- 获取设备自身IP地址，索引为设备下自身接口
         foreach my $self_interface ( keys %{ $device_rev->{"self_ip"} } ) {
 
             #获取当前接口下的IP地址详情
@@ -123,7 +124,7 @@ sub ip_info {
             }
         }
 
-		#阶段二 -- 获取设备下异常 arp 表项，索引为设备下自身接口
+        #阶段二 -- 获取设备下异常 arp 表项，索引为设备下自身接口
         foreach my $self_interface ( keys %{ $device_rev->{"incomplete"} } ) {
 
             #获取当前接口下的IP地址详情
@@ -152,7 +153,7 @@ sub ip_info {
             }
         }
 
- 		#阶段三 -- 计算设备当前的ARP表项，索引为设备下自身接口
+        #阶段三 -- 计算设备当前的ARP表项，索引为设备下自身接口
         foreach my $self_interface ( keys %{ $device_rev->{"dynamic"} } ) {
 
             #获取当前接口下的IP地址详情
@@ -182,14 +183,14 @@ sub ip_info {
                     #遍历当前eth_member接口发现的邻居下的MAC
                     foreach my $member ( @{$eth_member} ) {
 
-                 		#获取当前接口的邻居设备，输出为邻居设备名
+                        #获取当前接口的邻居设备，输出为邻居设备名
                         my $device_nei
                             = $nei_info->{$device}{$member}{"neighbor"};
 
                         #判断是否为 ipPhone
                         if ( $device_nei =~ /eSpace/i ) {
 
-               				#如果命中IP电话，将解析到的结果写入数据结构
+                            #如果命中IP电话，将解析到的结果写入数据结构
                             $ret4->{$ip_info}{"location"}  = $device_location;
                             $ret4->{$ip_info}{"hostname"}  = $device;
                             $ret4->{$ip_info}{"interface"} = $member;
@@ -211,7 +212,7 @@ sub ip_info {
                             #调取该设备的MAC地址对象
                             my $nei_mac = $mac_info->{$device_nei};
 
-           					#遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
+                            #遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
                             foreach my $nei_interface ( keys %{$nei_mac} ) {
 
                                 #获取当前邻居的MAC地址表
@@ -234,42 +235,57 @@ sub ip_info {
                                         && $mac eq $mac_rev )
                                     {
 
-                                      #将解析到的结果写入数据结构
-                                        $ret5->{$ip_info}{"location"} = $nei_location;
-                                        $ret5->{$ip_info}{"hostname"} = $device_nei;
+                                        #将解析到的结果写入数据结构
+                                        $ret5->{$ip_info}{"location"}
+                                            = $nei_location;
+                                        $ret5->{$ip_info}{"hostname"}
+                                            = $device_nei;
                                         $ret5->{$ip_info}{"vlan"} = $mac_vlan;
                                         $ret5->{$ip_info}{"mac"}  = $mac;
-                                        $ret5->{$ip_info}{"interface"} = $nei_interface;
-                                        $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret5->{$ip_info}{"gate_device"}  = $device;
+                                        $ret5->{$ip_info}{"interface"}
+                                            = $nei_interface;
+                                        $ret5->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret5->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
 
-                                 #判断MAC地址是否为 静态绑定 sticky
+                                   #判断MAC地址是否为 静态绑定 sticky
                                     elsif ($mac_type =~ /sticky/
                                         && $mac eq $mac_rev )
                                     {
 
-                                      #将解析到的结果写入数据结构
-                                        $ret4->{$ip_info}{"location"} = $nei_location;
-                                        $ret4->{$ip_info}{"hostname"} = $device_nei;
-                                        $ret4->{$ip_info}{"interface"} = $nei_interface;
+                                        #将解析到的结果写入数据结构
+                                        $ret4->{$ip_info}{"location"}
+                                            = $nei_location;
+                                        $ret4->{$ip_info}{"hostname"}
+                                            = $device_nei;
+                                        $ret4->{$ip_info}{"interface"}
+                                            = $nei_interface;
                                         $ret4->{$ip_info}{"mac"}  = $mac;
                                         $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                        $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret4->{$ip_info}{"gate_device"}  = $device;
+                                        $ret4->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret4->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
 
-                             		#进行逻辑判断，是否匹配当前ARP表项
+                                    #进行逻辑判断，是否匹配当前ARP表项
                                     elsif ( $mac eq $mac_rev ) {
 
-                                      	#将解析到的结果写入数据结构
-                                        $ret2->{$ip_info}{"location"} = $nei_location;
-                                        $ret2->{$ip_info}{"hostname"} = $device_nei;
+                                        #将解析到的结果写入数据结构
+                                        $ret2->{$ip_info}{"location"}
+                                            = $nei_location;
+                                        $ret2->{$ip_info}{"hostname"}
+                                            = $device_nei;
                                         $ret2->{$ip_info}{"vlan"} = $mac_vlan;
                                         $ret2->{$ip_info}{"mac"}  = $mac;
-                                        $ret2->{$ip_info}{"interface"} = $nei_interface;
-                                        $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret2->{$ip_info}{"gate_device"}  = $device;
+                                        $ret2->{$ip_info}{"interface"}
+                                            = $nei_interface;
+                                        $ret2->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret2->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
                                 }
                             }
@@ -281,7 +297,7 @@ sub ip_info {
                             #查找设备本身ETH-TRUNK下的接口MAC
                             my $dev_mac = $mac_info->{$device};
 
-    						#遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
+                            #遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
                             foreach my $dev_interface ( keys %{$dev_mac} ) {
 
                                 #获取当前邻居的MAC地址表
@@ -304,42 +320,54 @@ sub ip_info {
                                         && $mac eq $mac_rev )
                                     {
 
-                                      #将解析到的结果写入数据结构
-                                        $ret5->{$ip_info}{"location"} = $device_location;
+                                        #将解析到的结果写入数据结构
+                                        $ret5->{$ip_info}{"location"}
+                                            = $device_location;
                                         $ret5->{$ip_info}{"hostname"} = $device;
                                         $ret5->{$ip_info}{"vlan"} = $mac_vlan;
                                         $ret5->{$ip_info}{"mac"}  = $mac;
-                                        $ret5->{$ip_info}{"interface"} = $dev_interface;
-                                        $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret5->{$ip_info}{"gate_device"}  = $device;
+                                        $ret5->{$ip_info}{"interface"}
+                                            = $dev_interface;
+                                        $ret5->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret5->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
 
-                                 	#判断MAC地址是否为 静态绑定 sticky
+                                    #判断MAC地址是否为 静态绑定 sticky
                                     elsif ($mac_type =~ /sticky/
                                         && $mac eq $mac_rev )
                                     {
 
-                                      	#将解析到的结果写入数据结构
-                                        $ret4->{$ip_info}{"location"} = $device_location;
+                                        #将解析到的结果写入数据结构
+                                        $ret4->{$ip_info}{"location"}
+                                            = $device_location;
                                         $ret4->{$ip_info}{"hostname"} = $device;
                                         $ret4->{$ip_info}{"vlan"} = $mac_vlan;
                                         $ret4->{$ip_info}{"mac"}  = $mac;
-                                        $ret4->{$ip_info}{"interface"} = $dev_interface;
-                                        $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret4->{$ip_info}{"gate_device"}  = $device;
+                                        $ret4->{$ip_info}{"interface"}
+                                            = $dev_interface;
+                                        $ret4->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret4->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
 
-                             		#进行逻辑判断，是否匹配当前ARP表项
+                                    #进行逻辑判断，是否匹配当前ARP表项
                                     elsif ( $mac eq $mac_rev ) {
 
-                                      	#将解析到的结果写入数据结构
-                                        $ret2->{$ip_info}{"location"} = $device_location;
+                                        #将解析到的结果写入数据结构
+                                        $ret2->{$ip_info}{"location"}
+                                            = $device_location;
                                         $ret2->{$ip_info}{"hostname"} = $device;
                                         $ret2->{$ip_info}{"vlan"} = $mac_vlan;
                                         $ret2->{$ip_info}{"mac"}  = $mac;
-                                        $ret2->{$ip_info}{"interface"} = $dev_interface;
-                                        $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                        $ret2->{$ip_info}{"gate_device"}  = $device;
+                                        $ret2->{$ip_info}{"interface"}
+                                            = $dev_interface;
+                                        $ret2->{$ip_info}{"vpn_instance"}
+                                            = $vpn_instance;
+                                        $ret2->{$ip_info}{"gate_device"}
+                                            = $device;
                                     }
                                 }
                             }
@@ -353,14 +381,14 @@ sub ip_info {
                     #裁剪eth-trunk相关参数
                     $self_interface =~ s/\.\d+$//;
 
-                 	#获取当前接口的邻居设备，输出为邻居设备名
+                    #获取当前接口的邻居设备，输出为邻居设备名
                     my $device_nei
                         = $nei_info->{$device}{$self_interface}{"neighbor"};
 
                     #判断是否为 ipPhone
                     if ( $device_nei =~ /eSpace/i ) {
 
-               			#如果命中IP电话，将解析到的结果写入数据结构
+                         #如果命中IP电话，将解析到的结果写入数据结构
                         $ret4->{$ip_info}{"location"}     = $device_location;
                         $ret4->{$ip_info}{"hostname"}     = $device;
                         $ret4->{$ip_info}{"interface"}    = $self_interface;
@@ -382,7 +410,7 @@ sub ip_info {
                         #调取该设备的MAC地址对象
                         my $nei_mac = $mac_info->{$device_nei};
 
-           				#遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
+                        #遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
                         foreach my $nei_interface ( keys %{$nei_mac} ) {
 
                             #获取当前邻居的MAC地址表
@@ -406,13 +434,16 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret5->{$ip_info}{"location"} = $nei_location;
+                                    $ret5->{$ip_info}{"location"}
+                                        = $nei_location;
                                     $ret5->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret5->{$ip_info}{"interface"} = $nei_interface;
+                                    $ret5->{$ip_info}{"interface"}
+                                        = $nei_interface;
                                     $ret5->{$ip_info}{"mac"}  = $mac;
                                     $ret5->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                    $ret5->{$ip_info}{"gate_device"}  = $device;
+                                    $ret5->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
+                                    $ret5->{$ip_info}{"gate_device"} = $device;
                                 }
 
                                 #判断MAC地址是否为 静态绑定 sticky
@@ -421,26 +452,32 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret4->{$ip_info}{"location"} = $nei_location;
+                                    $ret4->{$ip_info}{"location"}
+                                        = $nei_location;
                                     $ret4->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret4->{$ip_info}{"interface"} = $nei_interface;
+                                    $ret4->{$ip_info}{"interface"}
+                                        = $nei_interface;
                                     $ret4->{$ip_info}{"mac"}  = $mac;
                                     $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                    $ret4->{$ip_info}{"gate_device"}  = $device;
+                                    $ret4->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
+                                    $ret4->{$ip_info}{"gate_device"} = $device;
                                 }
 
-                             #进行逻辑判断，是否匹配当前ARP表项
+                               #进行逻辑判断，是否匹配当前ARP表项
                                 elsif ( $mac eq $mac_rev ) {
 
                                     #将解析到的结果写入数据结构
-                                    $ret2->{$ip_info}{"location"} = $nei_location;
+                                    $ret2->{$ip_info}{"location"}
+                                        = $nei_location;
                                     $ret2->{$ip_info}{"hostname"} = $device_nei;
-                                    $ret2->{$ip_info}{"interface"} = $nei_interface;
+                                    $ret2->{$ip_info}{"interface"}
+                                        = $nei_interface;
                                     $ret2->{$ip_info}{"mac"}  = $mac;
                                     $ret2->{$ip_info}{"vlan"} = $mac_vlan;
-                                    $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                    $ret2->{$ip_info}{"gate_device"}  = $device;
+                                    $ret2->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
+                                    $ret2->{$ip_info}{"gate_device"} = $device;
                                 }
                             }
                         }
@@ -452,7 +489,7 @@ sub ip_info {
                         #查找设备本身ETH-TRUNK下的接口MAC
                         my $dev_mac = $mac_info->{$device};
 
-     					#遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
+                        #遍历设备本身的MAC地址信息，寻找能与当前ARP配对接口
                         foreach my $dev_interface ( keys %{$dev_mac} ) {
 
                             #获取当前邻居的MAC地址表
@@ -476,12 +513,15 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret5->{$ip_info}{"location"} = $device_location;
+                                    $ret5->{$ip_info}{"location"}
+                                        = $device_location;
                                     $ret5->{$ip_info}{"hostname"} = $device;
                                     $ret5->{$ip_info}{"vlan"}     = $mac_vlan;
                                     $ret5->{$ip_info}{"mac"}      = $mac;
-                                    $ret5->{$ip_info}{"interface"} = $dev_interface;
-                                    $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
+                                    $ret5->{$ip_info}{"interface"}
+                                        = $dev_interface;
+                                    $ret5->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
                                     $ret5->{$ip_info}{"gate_device"} = $device;
                                 }
 
@@ -491,26 +531,32 @@ sub ip_info {
                                 {
 
                                     #将解析到的结果写入数据结构
-                                    $ret4->{$ip_info}{"location"} = $device_location;
+                                    $ret4->{$ip_info}{"location"}
+                                        = $device_location;
                                     $ret4->{$ip_info}{"hostname"} = $device;
                                     $ret4->{$ip_info}{"vlan"}     = $mac_vlan;
                                     $ret4->{$ip_info}{"mac"}      = $mac;
-                                    $ret4->{$ip_info}{"interface"} = $dev_interface;
-                                    $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                    $ret4->{$ip_info}{"gate_device"}  = $device;
+                                    $ret4->{$ip_info}{"interface"}
+                                        = $dev_interface;
+                                    $ret4->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
+                                    $ret4->{$ip_info}{"gate_device"} = $device;
                                 }
 
-                             #进行逻辑判断，是否匹配当前ARP表项
+                                #进行逻辑判断，是否匹配当前ARP表项
                                 elsif ( $mac eq $mac_rev ) {
 
                                     #将解析到的结果写入数据结构
-                                    $ret2->{$ip_info}{"location"} = $device_location;
+                                    $ret2->{$ip_info}{"location"}
+                                        = $device_location;
                                     $ret2->{$ip_info}{"hostname"} = $device;
                                     $ret2->{$ip_info}{"vlan"}     = $mac_vlan;
                                     $ret2->{$ip_info}{"mac"}      = $mac;
-                                    $ret2->{$ip_info}{"interface"} = $dev_interface;
-                                    $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                    $ret2->{$ip_info}{"gate_device"}  = $device;
+                                    $ret2->{$ip_info}{"interface"}
+                                        = $dev_interface;
+                                    $ret2->{$ip_info}{"vpn_instance"}
+                                        = $vpn_instance;
+                                    $ret2->{$ip_info}{"gate_device"} = $device;
                                 }
                             }
                         }
@@ -520,7 +566,7 @@ sub ip_info {
                 #如果都没找到再次查找设备本身 MAC
                 else {
 
-           			#遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
+                    #遍历邻居的MAC地址信息，寻找能与当前ARP配对接口
                     foreach my $dev_interface ( keys %{$device_mac} ) {
 
                         #获取当前邻居的MAC地址表
@@ -542,41 +588,47 @@ sub ip_info {
                             if ( $mac_type =~ /authen/ && $mac eq $mac_rev ) {
 
                                 #将解析到的结果写入数据结构
-                                $ret5->{$ip_info}{"location"} = $device_location;
-                                $ret5->{$ip_info}{"hostname"} = $device;
+                                $ret5->{$ip_info}{"location"}
+                                    = $device_location;
+                                $ret5->{$ip_info}{"hostname"}  = $device;
                                 $ret5->{$ip_info}{"interface"} = $dev_interface;
-                                $ret5->{$ip_info}{"mac"}  = $mac;
-                                $ret5->{$ip_info}{"vlan"} = $mac_vlan;
-                                $ret5->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                $ret5->{$ip_info}{"gate_device"}  = $device;
+                                $ret5->{$ip_info}{"mac"}       = $mac;
+                                $ret5->{$ip_info}{"vlan"}      = $mac_vlan;
+                                $ret5->{$ip_info}{"vpn_instance"}
+                                    = $vpn_instance;
+                                $ret5->{$ip_info}{"gate_device"} = $device;
                             }
 
                             #判断MAC地址是否为 静态绑定 sticky
-                            elsif ( $mac_type =~ /sticky/
+                            elsif ($mac_type =~ /sticky/
                                 && $mac eq $mac_rev )
                             {
 
                                 #将解析到的结果写入数据结构
-                                $ret4->{$ip_info}{"location"} = $device_location;
-                                $ret4->{$ip_info}{"hostname"} = $device;
+                                $ret4->{$ip_info}{"location"}
+                                    = $device_location;
+                                $ret4->{$ip_info}{"hostname"}  = $device;
                                 $ret4->{$ip_info}{"interface"} = $dev_interface;
-                                $ret4->{$ip_info}{"mac"}  = $mac;
-                                $ret4->{$ip_info}{"vlan"} = $mac_vlan;
-                                $ret4->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                $ret4->{$ip_info}{"gate_device"}  = $device;
+                                $ret4->{$ip_info}{"mac"}       = $mac;
+                                $ret4->{$ip_info}{"vlan"}      = $mac_vlan;
+                                $ret4->{$ip_info}{"vpn_instance"}
+                                    = $vpn_instance;
+                                $ret4->{$ip_info}{"gate_device"} = $device;
                             }
 
                             #进行逻辑判断，是否匹配当前ARP表项
                             elsif ( $mac eq $mac_rev ) {
 
                                 #将解析到的结果写入数据结构
-                                $ret2->{$ip_info}{"location"} = $device_location;
-                                $ret2->{$ip_info}{"hostname"} = $device;
+                                $ret2->{$ip_info}{"location"}
+                                    = $device_location;
+                                $ret2->{$ip_info}{"hostname"}  = $device;
                                 $ret2->{$ip_info}{"interface"} = $dev_interface;
-                                $ret2->{$ip_info}{"mac"}  = $mac;
-                                $ret2->{$ip_info}{"vlan"} = $mac_vlan;
-                                $ret2->{$ip_info}{"vpn_instance"} = $vpn_instance;
-                                $ret2->{$ip_info}{"gate_device"}  = $device;
+                                $ret2->{$ip_info}{"mac"}       = $mac;
+                                $ret2->{$ip_info}{"vlan"}      = $mac_vlan;
+                                $ret2->{$ip_info}{"vpn_instance"}
+                                    = $vpn_instance;
+                                $ret2->{$ip_info}{"gate_device"} = $device;
                             }
                         }
                     }
@@ -594,7 +646,7 @@ sub ip_info {
         }
     }
 
-	#处理解析成功且出现在未解析ret6中的重复项，（设备无序）
+    #处理解析成功且出现在未解析ret6中的重复项，（设备无序）
     foreach my $ip ( keys %{$ret6} ) {
 
         #进行条件判断，如出现在ret1 ret2 ret4 ret5 中则剔除
@@ -609,7 +661,7 @@ sub ip_info {
         }
     }
 
-	#处理解析成功且出现在未解析ret5中的重复项，（设备无序）
+    #处理解析成功且出现在未解析ret5中的重复项，（设备无序）
     foreach my $ip ( keys %{$ret5} ) {
 
         #进行条件判断，如出现在ret1 ret2 ret4中则剔除
@@ -623,7 +675,7 @@ sub ip_info {
         }
     }
 
-	#处理解析成功且出现在未解析ret5中的重复项，（设备无序）
+    #处理解析成功且出现在未解析ret5中的重复项，（设备无序）
     foreach my $ip ( keys %{$ret2} ) {
 
         #进行条件判断，如出现在ret1 ret4 ret5 中则剔除
@@ -762,10 +814,13 @@ sub device_arp {
                 #封装特定的数据结构
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"} = "Incomplete";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"} = $exp_time || "forever";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}
+                    = $exp_time || "forever";
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"} = undef;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"} = $interface;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}
+                    = $interface;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"}
+                    = $vpn_instance;
 
                 #继续下一个迭代
                 next;
@@ -789,9 +844,10 @@ sub device_arp {
             #输出解析结果
             $ret->{$type}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
             $ret->{$type}{$interface}{$ipaddr}{"mac"}    = $mac;
-            $ret->{$type}{$interface}{$ipaddr}{"exp_time"} = $exp_time || "forever";
-            $ret->{$type}{$interface}{$ipaddr}{"vlan"}      = undef;
-            $ret->{$type}{$interface}{$ipaddr}{"interface"} = $interface;
+            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}
+                = $exp_time || "forever";
+            $ret->{$type}{$interface}{$ipaddr}{"vlan"}         = undef;
+            $ret->{$type}{$interface}{$ipaddr}{"interface"}    = $interface;
             $ret->{$type}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
         }
 
@@ -816,10 +872,13 @@ sub device_arp {
                 #封装特定的数据结构
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"mac"} = "Incomplete";
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"} = $exp_time || "forever";
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"exp_time"}
+                    = $exp_time || "forever";
                 $ret->{"incomplete"}{$interface}{$ipaddr}{"vlan"} = $vlan;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"} = $interface;
-                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"interface"}
+                    = $interface;
+                $ret->{"incomplete"}{$interface}{$ipaddr}{"vpn_instance"}
+                    = $vpn_instance;
 
                 #继续下一个迭代
                 next;
@@ -844,9 +903,10 @@ sub device_arp {
             #输出解析结果
             $ret->{$type}{$interface}{$ipaddr}{"ipaddr"} = $ipaddr;
             $ret->{$type}{$interface}{$ipaddr}{"mac"}    = $mac;
-            $ret->{$type}{$interface}{$ipaddr}{"exp_time"} = $exp_time || "forever";
-            $ret->{$type}{$interface}{$ipaddr}{"vlan"}      = $vlan;
-            $ret->{$type}{$interface}{$ipaddr}{"interface"} = $interface;
+            $ret->{$type}{$interface}{$ipaddr}{"exp_time"}
+                = $exp_time || "forever";
+            $ret->{$type}{$interface}{$ipaddr}{"vlan"}         = $vlan;
+            $ret->{$type}{$interface}{$ipaddr}{"interface"}    = $interface;
             $ret->{$type}{$interface}{$ipaddr}{"vpn_instance"} = $vpn_instance;
         }
     }
@@ -876,8 +936,7 @@ sub device_mac {
         if ( $cli =~ $mac_str ) {
 
             #实例化变量
-            my ( $mac, $vlan_vsi_bd, $interface, $type )
-                = split( /\s+/, $cli );
+            my ( $mac, $vlan_vsi_bd, $interface, $type ) = split( /\s+/, $cli );
 
             #抽取MAC对应的VLAN信息
             my ( $vlan, $vsi, $bd ) = split( /\//, $vlan_vsi_bd );
@@ -885,7 +944,7 @@ sub device_mac {
             #过滤非物理接口
             if ( $interface =~ /GE|Vlanif|Eth\d/i ) {
 
-              #输出匹配信息 如果未命中VLAN则使用VXLAN的BD绑定
+                #输出匹配信息 如果未命中VLAN则使用VXLAN的BD绑定
                 if ( $vlan && $vlan ne '-' ) {
                     $ret->{$interface}{$mac} = "VLAN/" . $vlan;
                 }
